diff OrthancServer/OrthancRestApi.h @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 6da7fc87efaa
children fe180eae201d
line wrap: on
line diff
--- a/OrthancServer/OrthancRestApi.h	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/OrthancRestApi.h	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -27,9 +27,9 @@
 #include <set>
 
 
-namespace Palanthir
+namespace Orthanc
 {
-  class PalanthirRestApi : public HttpHandler
+  class OrthancRestApi : public HttpHandler
   {
   private:
     typedef std::set<std::string> Modalities;
@@ -68,7 +68,7 @@
                     const std::string& postData);
 
   public:
-    PalanthirRestApi(ServerIndex& index,
+    OrthancRestApi(ServerIndex& index,
                      const std::string& path);
 
     virtual bool IsServedUri(const UriComponents& uri)
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium